CON
           
' *******************************************************************************************************
' *                                                                                                     *
' *     AiChip 16Kx8 I2C Ram                                          AiChip_I2cSlave_16Kx8Ram_005      *
' *                                                                                                     *
' *******************************************************************************************************
' *                                                                                                     *
' *     Object Name    : AiChip I2C Slave 16Kx8 Ram                                                     *
' *     Version        : 005                                                                            *
' *     Updated        : 2008-04-13                                                                     *
' *                                                                                                     *
' *     Author         : AiChip Industries                                                              *
' *                                                                                                     *
' *     Copyright      : 2008, AiChip Industries                                                        *
' *                                                                                                     *
' *     Target Chip    : Parallax Propeller Chip P8X32A ( "Propeller Mk I" )                            *
' *     Compiler Used  : Parallax Propeller Tool 1.1                                                    *
' *                                                                                                     *
' *     License        : MIT License. Please see end of this file for Terms of Use.                     *
' *                                                                                                     *
' *******************************************************************************************************
' *                                                                                                     *
' *     AiChip is a trademark of AiChip Industries.                                                     *
' *                                                                                                     *
' *     If distributing a modified version of this software AiChip Industries requests the "AiChip"     *
' *     prefix be removed from the filename and internal text descriptions to avoid any confusion that  *
' *     may be caused by an impression that the modified software originates from AiChip Industries.    *
' *                                                                                                     *
' *******************************************************************************************************

' *******************************************************************************************************
' *                                                                                                     *
' *     HISTORY                                                                                         *
' *                                                                                                     *
' *     005     2008-04-13      First Public Release                                                    *
' *                                                                                                     *
' *******************************************************************************************************

PRI Version

  result := String( "AiChip_I2cSlave_16Kx8Ram_005" )
  
CON

  _CLKMODE      = XTAL1 + PLL16x
  _XINFREQ      = 5_000_000

  TV_PIN        = 12
  
  SDA_PIN       = 29
  SCL_PIN       = 28

  DEVICE_ID     = $E0
  
OBJ

  tv            : "TV_Text"
  
  i2c_Slave     : "AiChip_I2cSlave_Slave_005"
  i2c_Master    : "AiChip_I2cSlave_Master_005"
  
PUB Main | testNum, pc, n

  tv.Start( TV_PIN )

  ' Start the I2C Slave running. It uses the same I2C lines as the master does so no wiring needed.
  
  i2c_Slave.Start( SCL_PIN, SDA_PIN, DEVICE_ID, $4000, 16*1024 )

  ' Allow the I2C Slave time to start so we can be sure that starting the I2C Master doesn't cause it any
  ' problems when kicking the I2C bus into life.
  
  WaitCnt( CLKFREQ / 1000 * 100 + CNT )

  i2c_Master.OpenRaw( SCL_PIN, SDA_PIN, DEVICE_ID, 0, 0 )

  ' Test all bit combination of the 16K I2C Ram
  
  repeat testNum from $00 to $FF

    Header
    tv.Str( String( $0D,$0D,"Test : " ) )
    tv.Hex( testNum, 2 )
    if testNum
      tv.Str( String( " - Okay so far" ) )

    n := testNum
    repeat pc from 0 to (16*1024)-1
      i2c_master.WriteByte( pc, n++ )
      if n == 0
        n++

    n := testNum
    repeat pc from 0 to (16*1024)-1
      Check( pc, n++ )
      if n == 0
        n++

  tv.Str( String( $0D,$0D,"PASSED ALL TESTS") )

PRI Header

  tv.Out( $01 )
  tv.Str( Version )
  tv.Out( $0D )
  tv.Str( i2c_Slave.Version )
  ShowId( DEVICE_ID )
  tv.Str( i2c_Master.Version )

PRI ShowId( id )

  tv.Str( String( " : " ) )
  if id & $10_000
    tv.Str( String( "10_" ) )
    tv.hex( id, 3 )
  else
    tv.Hex( id, 2 )
  tv.Out( $0D )
  
PRI Check( pc, n )

  n &= $FF
  
  if ( result := i2c_Master.ReadByte( pc ) ) <> n
     tv.Str( String( $0D,$0D,"FAILED : At " ) )
     tv.Hex( pc, 4 )
     tv.Str( String( " Wrote ") )
     tv.Hex( n , 2 )
     tv.Str( String( " Read ") )
     tv.Hex( result, 2 )
     repeat
  
CON

' *******************************************************************************************************
' *                                                                                                     *
' *     Terms of Use : MIT License                                                                      *
' *                                                                                                     *
' *******************************************************************************************************
'
' Permission is hereby granted, free of charge, to any person obtaining a copy of this software and
' associated documentation files (the "Software"), to deal in the Software without restriction, including
' without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
' copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to
' the following conditions:                                                                   
'
' The above copyright notice and this permission notice shall be included in all copies or substantial
' portions of the Software.                                                                                             
'                                                                                                                  
' THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
' LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN
' NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
' WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
' SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

CON

' *******************************************************************************************************
' *                                                                                                     *
' *     End of AiChip 16Kx8 I2C Ram                                                                     *
' *                                                                                                     *
' *******************************************************************************************************
        